@@ -3,11 +3,11 @@ package cloud
 import (
 	"fmt"
 
-	configv1alpha1 "github.com/open-cluster-management/submariner-addon/pkg/apis/submarinerconfig/v1alpha1"
-	"github.com/open-cluster-management/submariner-addon/pkg/cloud/aws"
-	"github.com/open-cluster-management/submariner-addon/pkg/cloud/gcp"
-	"github.com/open-cluster-management/submariner-addon/pkg/helpers"
 	"github.com/openshift/library-go/pkg/operator/events"
+	configv1alpha1 "github.com/stolostron/submariner-addon/pkg/apis/submarinerconfig/v1alpha1"
+	"github.com/stolostron/submariner-addon/pkg/cloud/aws"
+	"github.com/stolostron/submariner-addon/pkg/cloud/gcp"
+	"github.com/stolostron/submariner-addon/pkg/helpers"
 	"k8s.io/apimachinery/pkg/api/meta"
 	"k8s.io/client-go/dynamic"
 	"k8s.io/client-go/kubernetes"
